// generated 2001/4/7 23:38:20 PDT by vadim@voyager.
// using glademm V0.5_11f_cvs
//
// newer (non customized) versions of this file go to ASDruidP47Dialog.cc_new

// This file is for your program, I won't touch it again!

#include "config.h"
#include "ASDruidP47Dialog.hh"
#include "helpers.hh"
#include "FWObjectDatabaseGUI.hh"

using namespace libfwbuilder;

ASDruidP47Dialog::ASDruidP47Dialog()
{
    FWObject *frag;
    frag=_findObjectByName(FWObjectDatabaseGUI::getServicesId(),"ip_fragments");
    if (frag==NULL) short_fragments->set_sensitive(false);

    setButtonLblAlignment(anti_spoof_in   , 0.0, 0.5);
    setButtonLblAlignment(anti_spoof_out  , 0.0, 0.5);
    setButtonLblAlignment(short_fragments , 0.0, 0.5);
    setButtonLblAlignment(allow_all_on_loopback   , 0.0, 0.5);
    setButtonLblAlignment(masquerading    , 0.0, 0.5);
    setButtonLblAlignment(catch_all       , 0.0, 0.5);

    p47_txt_1->set_line_wrap(true);
    p47_txt_2->set_line_wrap(true);
}

